@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.ChimeSDKIdentity 1.21.23\nVersion:        "
-        " 1.21.23.post1\nBuilder version: 7.4.1\nDocs:           "
+        "Type annotations for boto3.ChimeSDKIdentity 1.21.27\nVersion:         1.21.27\nBuilder"
+        " version: 7.5.3\nDocs:           "
         " https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity//\nBoto3 docs:    "
         "  https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-identity.html#ChimeSDKIdentity\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.23.post1")
+    print("1.21.27")
 
 
 def main() -> None:
